
# ![pterosaur flying icon](docs/assets/icons8-pterodactyl-48.svg) DACTYL Generation
![PyPI](https://img.shields.io/pypi/v/dactyl-generation?label=pypi%20package) [![PyPI Downloads](https://static.pepy.tech/personalized-badge/dactyl-generation?period=total&units=INTERNATIONAL_SYSTEM&left_color=BLACK&right_color=BRIGHTGREEN&left_text=downloads)](https://pepy.tech/projects/dactyl-generation) [![arXiv](https://img.shields.io/badge/arXiv-2508.00619-b31b1b.svg)](https://arxiv.org/abs/2508.00619) [![Hugging Face](https://img.shields.io/badge/Hugging%20Face-FFD21E?logo=huggingface&logoColor=000)](https://huggingface.co/datasets/ShantanuT01/DACTYL)
## About

`dactyl-generation` is a Python library developed to support batch inference text generation from different LLM APIs.

Batch inference enables sending multiple prompts at once, often at a 50% discount compared to standard streaming or live APIs.

## Installation and Setup

```bash
pip install dactyl-generation
```

Check the `examples/` directories to see how to use different batch inference providers seamlessly. 


## Supported Providers

We support the following LLM API providers.

- OpenAI
- Anthropic
- Mistral
- Google (Gemini)
- AWS Bedrock
- Fireworks AI



Icons by [Icons8](https://icons8.com/). 
